# -*- coding: utf-8 -*-

from __future__ import unicode_literals  # unicode support for py2

# Heroku links
HEROKU_TROUBLESHOOT_URL = "https://devcenter.heroku.com/categories/troubleshooting"
HEROKU_API_KEY_HELP_URL = "https://devcenter.heroku.com/articles/authentication#retrieving-the-api-token"
